pub enum DeleteAccessError {
InternalServiceError(String),
InvalidRequest(String),
ResourceNotFound(String),
ServiceUnavailable(String),
}Expand description
Errors returned by DeleteAccess
Variants
InternalServiceError(String)
This exception is thrown when an error occurs in the Amazon Web ServicesTransfer Family service.
InvalidRequest(String)
This exception is thrown when the client submits a malformed request.
ResourceNotFound(String)
This exception is thrown when a resource is not found by the Amazon Web ServicesTransfer Family service.
The request has failed because the Amazon Web ServicesTransfer Family service is not available.
Implementations
Sourceimpl DeleteAccessError
impl DeleteAccessError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<DeleteAccessError>