pub enum ListServersError {
InternalServiceError(String),
InvalidNextToken(String),
InvalidRequest(String),
ServiceUnavailable(String),
}Expand description
Errors returned by ListServers
Variants
InternalServiceError(String)
This exception is thrown when an error occurs in the AWS Transfer Family service.
InvalidNextToken(String)
The NextToken parameter that was passed is invalid.
InvalidRequest(String)
This exception is thrown when the client submits a malformed request.
The request has failed because the AWS Transfer Family service is not available.
Implementations
Sourceimpl ListServersError
impl ListServersError
pub fn from_response(res: BufferedHttpResponse) -> RusotoError<ListServersError>