pub enum TestIdentityProviderError {
InternalServiceError(String),
InvalidRequest(String),
ResourceNotFound(String),
ServiceUnavailable(String),
}Expand description
Errors returned by TestIdentityProvider
Variants
InternalServiceError(String)
This exception is thrown when an error occurs in the AWS Transfer Family service.
InvalidRequest(String)
This exception is thrown when the client submits a malformed request.
ResourceNotFound(String)
This exception is thrown when a resource is not found by the AWS Transfer Family service.
The request has failed because the AWS Transfer Family service is not available.
Implementations
Sourceimpl TestIdentityProviderError
impl TestIdentityProviderError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<TestIdentityProviderError>