pub struct DeleteUserRequest {
pub server_id: String,
pub user_name: String,
}Fields
server_id: StringA system-assigned unique identifier for a file transfer protocol-enabled server instance that has the user assigned to it.
user_name: StringA unique string that identifies a user that is being deleted from a file transfer protocol-enabled server.