pub struct ListUsersRequest {
pub max_results: Option<i64>,
pub next_token: Option<String>,
pub server_id: String,
}Fields
max_results: Option<i64>Specifies the number of users to return as a response to the ListUsers request.
next_token: Option<String>When you can get additional results from the ListUsers call, a NextToken parameter is returned in the output. You can then pass in a subsequent command to the NextToken parameter to continue listing additional users.
server_id: StringA system-assigned unique identifier for a file transfer protocol-enabled server that has users assigned to it.