pub struct ListUsersResponse {
pub next_token: Option<String>,
pub server_id: String,
pub users: Vec<ListedUser>,
}Fields
next_token: Option<String>When you can get additional results from the ListUsers call, a NextToken parameter is returned in the output. You can then pass in a subsequent command to the NextToken parameter to continue listing additional users.
server_id: StringA system-assigned unique identifier for a file transfer protocol-enabled server that the users are assigned to.
users: Vec<ListedUser>Returns the user accounts and their properties for the ServerId value that you specify.