pub struct TestIdentityProviderResponse {
pub message: Option<String>,
pub response: Option<String>,
pub status_code: i64,
pub url: String,
}Fields
message: Option<String>A message that indicates whether the test was successful or not.
response: Option<String>The response that is returned from your API Gateway.
status_code: i64The HTTP status code that is the response from your API Gateway.
url: StringThe endpoint of the service used to authenticate a user.