TransferClient

Struct TransferClient 

pub struct TransferClient { /* private fields */ }
A client for the AWS Transfer API.

Implementations

Source

impl TransferClient

pub fn new(region: Region) -> TransferClient

Creates a client backed by the default tokio event loop.

The client will use the default credentials provider and tls client.

pub fn new_with<P, D>( request_dispatcher: D, credentials_provider: P, region: Region, ) -> TransferClient
where P: ProvideAwsCredentials + Send + Sync + 'static, D: DispatchSignedRequest + Send + Sync + 'static,

pub fn new_with_client(client: Client, region: Region) -> TransferClient