pub struct UpdateUserResponse {
pub server_id: String,
pub user_name: String,
}Expand description
UpdateUserResponse returns the user name and file transfer protocol-enabled server identifier for the request to update a user's properties.
Fields
server_id: StringA system-assigned unique identifier for a file transfer protocol-enabled server instance that the user account is assigned to.
user_name: StringThe unique identifier for a user that is assigned to a file transfer protocol-enabled server instance that was specified in the request.