pub struct TransferClient { /* private fields */ }Expand description
A client for the AWS Transfer API.
Implementations
Sourceimpl TransferClient
impl TransferClient
Sourcepub fn new(region: Region) -> TransferClient
pub fn new(region: Region) -> TransferClient
Creates a client backed by the default tokio event loop.
The client will use the default credentials provider and tls client.
pub fn new_with<P, D>(
request_dispatcher: D,
credentials_provider: P,
region: Region,
) -> TransferClientwhere
P: ProvideAwsCredentials + Send + Sync + 'static,
D: DispatchSignedRequest + Send + Sync + 'static,
pub fn new_with_client(client: Client, region: Region) -> TransferClient